$wnd.rstudio.runAsyncCallback14("function jfm(a){this.a=a}\nfunction azm(){pvf.call(this)}\nfunction dph(a,b){ooh(a,cgn,'svn_cleanup',new tE,b)}\nfunction ffm(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=pym(a.a.b.a);a5h(a.a,a.a.a)}switch(a.c){case 1:a.a.a.c.G.qE();break;case 2:a.a.a.c.G.rE();break;case 3:a.a.a.c.G.sE();break;case 4:vem(a.a.a,a.b[0]);break;case 5:wem(a.a.a,a.b[0]);break;case 6:a.a.a.c.sK();break;case 7:a.a.a.c.tK();break;case 8:a.a.a.c.uK();break;case 9:a.a.a.c.vK();break;case 10:a.a.a.c.wK();break;case 11:a.a.a.c.xK();break;case 12:xem(a.a.a,a.b[0]);break;case 13:a.a.a.c.yK();break;case 14:yem(a.a.a,a.b[0]);break;case 15:a.a.a.c.G.tE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nkVc(275,1,dfn);_.xm=function ifm(){ffm((new jfm(this)).a)};kVc(6148,1,oRm,jfm);_.zm=function kfm(){ffm(this.a)};var cNc=wBd(6148);kVc(7231,1547,s9m);_.sK=function Ism(){};_.tK=function Jsm(){Fsm(this,false,null,tfm(this.i.k))};_.uK=function Ksm(){ktm(this.b,tfm(this.i.k))};_.vK=function Lsm(){Tlh(this.b.c,new otm)};_.wK=function Msm(){Ulh(this.b.c,new qtm)};_.xK=function Nsm(){Vlh(this.b.c,new stm)};_.yK=function Osm(){Fsm(this,true,null,new xbd)};kVc(6053,52,{},azm);_.vt=function bzm(a){ede(new Zgm(a),true)};var TRc=wBd(6053);kVc(7239,1547,s9m);_.sK=function _zm(){dph(this.c,new Xhm('SVN Cleanup','Cleaning up working directory...',750))};_.tK=function aAm(){ede(kCm(this.a.d.a),true)};_.uK=function bAm(){Jym(this.a)};_.vK=function cAm(){oph(this.a.f,new $ym)};_.wK=function dAm(){oph(this.a.f,new azm)};_.xK=function eAm(){};_.yK=function fAm(){Yzm(this,null,new xbd)};nIm(El)(14);\n//# sourceURL=rstudio-14.js\n")
