$wnd.rstudio.runAsyncCallback15("function WDi(){}\nfunction lDi(a){this.a=a}\nfunction UDi(a){this.a=a}\nfunction ZDi(a){this.a=a}\nfunction _Di(a){this.a=a}\nfunction _Ei(a){this.a=a}\nfunction GXf(a){this.a=a}\nfunction QCi(a){aDi(a,new ZDi(a))}\nfunction VCi(a){cWf(a.b,new _Di(a))}\nfunction UCi(a){Oik(a.k,new UDi(a),new WDi,FFn)}\nfunction XCi(a){Oik(a.k,new ODi(a,null),new QDi,bMn)}\nfunction YCi(a,b){azf(a.d,new wVi(b,true),false)}\nfunction nWf(a,b){(IVd(b),b)&&$Ci(a.a,qFo,'')}\nfunction nDi(a,b){this.a=a;this.b=b;ROf.call(this)}\nfunction YDi(a,b){YCi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction _Gh(a,b){GLh(a,VIn,'devtools_load_all_path',new lH,b)}\nfunction aDi(a,b){a.c!=null?YDi(b,a.c):_Gh(a.i,new nDi(a,b))}\nfunction WCi(a){a.H.RG();Fm((ym(),xm),new lDi(a))}\nfunction jDi(){PNf.call(this,'Terminating Build...')}\nfunction cWf(a,b){QVf(a,pFo,pFo,fYf(a.g.b.package_dependencies,'roxygen'),DVf(a,'roxygen'),false,new GXf(b))}\nfunction NCi(a,b){var c,d;SPf(a.p.e,null);d=b.outputs;for(c=0;c<d.length;c++)iCi(a.p,d[c]);b.errors.length>0&&hCi(a.p,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?O4d(a.a.Cj,true,false):RPf(a.p.e);MXe(a.p.e.c.c)}\nfunction XEi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=AFi(a.a.b.a);tsi(a.a,a.a.a)}switch(a.c){case 1:NCi(a.a.a,a.b[0]);break;case 2:a.a.a.H.PG();break;case 3:a.a.a.H.QG();break;case 4:$Ci(a.a.a,Umo,'');break;case 5:$Ci(a.a.a,'build-binary-package','');break;case 6:$Ci(a.a.a,'build-source-package','');break;case 7:$Ci(a.a.a,'check-package','');break;case 8:$Ci(a.a.a,'clean-all','');break;case 9:UCi(a.a.a);break;case 10:$Ci(a.a.a,Vmo,'');break;case 11:VCi(a.a.a);break;case 12:WCi(a.a.a);break;case 13:XCi(a.a.a);break;case 14:IMh(a.a.a.i,new jDi);break;case 15:$Ci(a.a.a,'test-package','');break;case 18:a.a.a.H.SG();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nvar pFo='Building package documentation',qFo='roxygenize-package';CZc(2178,1,Ken,GXf);_.ot=function HXf(a){nWf(this.a,a)};var Xjb=eHd(2178);CZc(6648,372,{},jDi);_.nm=function kDi(a){(IVd(a),a)||SYc().TB(3,'Error Terminating Build','Unable to terminate build. Please try again.').UB()};var jTb=eHd(6648);CZc(6649,1,Pen,lDi);_.zm=function mDi(){MXe(this.a.p.e.c.c)};var kTb=eHd(6649);CZc(6650,53,{},nDi);_.uu=function oDi(a){this.a.c=a;YDi(this.b,this.a.c)};var lTb=eHd(6650);CZc(6641,1,Pen,UDi);_.zm=function VDi(){QCi(this.a)};var BTb=eHd(6641);CZc(6642,1,Pen,WDi);_.zm=function XDi(){};var CTb=eHd(6642);CZc(6640,1,Ken,ZDi);_.ot=function $Di(a){YDi(this,a)};var DTb=eHd(6640);CZc(6643,1,Pen,_Di);_.zm=function aEi(){$Ci(this.a,qFo,'')};var ETb=eHd(6643);CZc(250,1,WHn);_.xm=function $Ei(){XEi((new _Ei(this)).a)};CZc(6211,1,Pen,_Ei);_.zm=function aFi(){XEi(this.a)};var $Tb=eHd(6211);F5m(Gl)(15);\n//# sourceURL=rstudio-15.js\n")
