function rstudio(){var O='bootstrap',P='begin',Q='gwt.codesvr.rstudio=',R='gwt.codesvr=',S='rstudio',T='startup',U='DUMMY',V=0,W=1,X='iframe',Y='position:absolute; width:0; height:0; border:none; left: -1000px;',Z=' top: -1000px;',$='aria-hidden',_='true',ab='CSS1Compat',bb='<!doctype html>',cb='',db='<html><head><\/head><body><\/body><\/html>',eb='undefined',fb='readystatechange',gb=10,hb='Chrome',ib='eval("',jb='");',kb='script',lb='javascript',mb='moduleStartup',nb='moduleRequested',ob='Failed to load ',pb='head',qb='meta',rb='name',sb='rstudio::',tb='::',ub='gwt:property',vb='content',wb='=',xb='gwt:onPropertyErrorFn',yb='Bad handler "',zb='" for "gwt:onPropertyErrorFn"',Ab='gwt:onLoadErrorFn',Bb='" for "gwt:onLoadErrorFn"',Cb='#',Db='?',Eb='/',Fb='img',Gb='clear.cache.gif',Hb='baseUrl',Ib='rstudio.nocache.js',Jb='base',Kb='//',Lb='compiler.stackMode',Mb=2,Nb='rstudio.desktop',Ob='Electron',Pb='QtWebEngine',Qb='false',Rb='rstudio.remoteDesktop',Sb='RStudio Remote Desktop',Tb='user.agent',Ub='webkit',Vb='safari',Wb='msie',Xb=11,Yb='ie10',Zb=9,$b='ie9',_b=8,ac='ie8',bc='gecko',cc='gecko1_8',dc=3,ec=4,fc='selectingPermutation',gc='rstudio.devmode.js',hc='emulated',ic='0E32CB859AADA843E595B932A544D5AF',jc=':1',kc=':2',lc=':3',mc='296E122B27F3AC60FC74BCB0A74E33CF',nc='native',oc='3241016E079ECEC00C564C7D094FF276',pc='84A707C7B13FF9F81F1BF625B97D82CE',qc='9CEC9D46F967962FD9AC64089659E55B',rc='B428907A7CBAA550EBCF34077ED744DC',sc='CCE2EE8D24533927030CE81F73D2C3EE',tc='F8D39F466CDF6B1F6F0F20DDD66CA79B',uc=':',vc='.cache.js',wc='loadExternalRefs',xc='end',yc='http:',zc='file:',Ac='_gwt_dummy_',Bc='__gwtDevModeHook:rstudio',Cc='Ignoring non-whitelisted Dev Mode URL: ',Dc=':moduleBase';var o=window;var p=document;r(O,P);function q(){var a=o.location.search;return a.indexOf(Q)!=-1||a.indexOf(R)!=-1}
function r(a,b){if(o.__gwtStatsEvent){o.__gwtStatsEvent({moduleName:S,sessionId:o.__gwtStatsSessionId,subSystem:T,evtGroup:a,millis:(new Date).getTime(),type:b})}}
rstudio.__sendStats=r;rstudio.__moduleName=S;rstudio.__errFn=null;rstudio.__moduleBase=U;rstudio.__softPermutationId=V;rstudio.__computePropValue=null;rstudio.__getPropMap=null;rstudio.__installRunAsyncCode=function(){};rstudio.__gwtStartLoadingFragment=function(){return null};rstudio.__gwt_isKnownPropertyValue=function(){return false};rstudio.__gwt_getMetaProperty=function(){return null};var s=null;var t=o.__gwt_activeModules=o.__gwt_activeModules||{};t[S]={moduleName:S};rstudio.__moduleStartupDone=function(e){var f=t[S].bindings;t[S].bindings=function(){var a=f?f():{};var b=e[rstudio.__softPermutationId];for(var c=V;c<b.length;c++){var d=b[c];a[d[V]]=d[W]}return a}};var u;function v(){w();return u}
function w(){if(u){return}var a=p.createElement(X);a.id=S;a.style.cssText=Y+Z;a.tabIndex=-1;a.setAttribute($,_);p.body.appendChild(a);u=a.contentWindow.document;u.open();var b=document.compatMode==ab?bb:cb;u.write(b+db);u.close()}
function A(k){function l(a){function b(){if(typeof p.readyState==eb){return typeof p.body!=eb&&p.body!=null}return /loaded|complete/.test(p.readyState)}
var c=b();if(c){a();return}function d(){if(!c){if(!b()){return}c=true;a();if(p.removeEventListener){p.removeEventListener(fb,d,false)}if(e){clearInterval(e)}}}
if(p.addEventListener){p.addEventListener(fb,d,false)}var e=setInterval(function(){d()},gb)}
function m(c){function d(a,b){a.removeChild(b)}
var e=v();var f=e.body;var g;if(navigator.userAgent.indexOf(hb)>-1&&window.JSON){var h=e.createDocumentFragment();h.appendChild(e.createTextNode(ib));for(var i=V;i<c.length;i++){var j=window.JSON.stringify(c[i]);h.appendChild(e.createTextNode(j.substring(W,j.length-W)))}h.appendChild(e.createTextNode(jb));g=e.createElement(kb);g.language=lb;g.appendChild(h);f.appendChild(g);d(f,g)}else{for(var i=V;i<c.length;i++){g=e.createElement(kb);g.language=lb;g.text=c[i];f.appendChild(g);d(f,g)}}}
rstudio.onScriptDownloaded=function(a){l(function(){m(a)})};r(mb,nb);var n=p.createElement(kb);n.src=k;if(rstudio.__errFn){n.onerror=function(){rstudio.__errFn(S,new Error(ob+code))}}p.getElementsByTagName(pb)[V].appendChild(n)}
rstudio.__startLoadingFragment=function(a){return D(a)};rstudio.__installRunAsyncCode=function(a){var b=v();var c=b.body;var d=b.createElement(kb);d.language=lb;d.text=a;c.appendChild(d);c.removeChild(d)};function B(){var c={};var d;var e;var f=p.getElementsByTagName(qb);for(var g=V,h=f.length;g<h;++g){var i=f[g],j=i.getAttribute(rb),k;if(j){j=j.replace(sb,cb);if(j.indexOf(tb)>=V){continue}if(j==ub){k=i.getAttribute(vb);if(k){var l,m=k.indexOf(wb);if(m>=V){j=k.substring(V,m);l=k.substring(m+W)}else{j=k;l=cb}c[j]=l}}else if(j==xb){k=i.getAttribute(vb);if(k){try{d=eval(k)}catch(a){alert(yb+k+zb)}}}else if(j==Ab){k=i.getAttribute(vb);if(k){try{e=eval(k)}catch(a){alert(yb+k+Bb)}}}}}__gwt_getMetaProperty=function(a){var b=c[a];return b==null?null:b};s=d;rstudio.__errFn=e}
function C(){function e(a){var b=a.lastIndexOf(Cb);if(b==-1){b=a.length}var c=a.indexOf(Db);if(c==-1){c=a.length}var d=a.lastIndexOf(Eb,Math.min(c,b));return d>=V?a.substring(V,d+W):cb}
function f(a){if(a.match(/^\w+:\/\//)){}else{var b=p.createElement(Fb);b.src=a+Gb;a=e(b.src)}return a}
function g(){var a=__gwt_getMetaProperty(Hb);if(a!=null){return a}return cb}
function h(){var a=p.getElementsByTagName(kb);for(var b=V;b<a.length;++b){if(a[b].src.indexOf(Ib)!=-1){return e(a[b].src)}}return cb}
function i(){var a=p.getElementsByTagName(Jb);if(a.length>V){return a[a.length-W].href}return cb}
function j(){var a=p.location;return a.href==a.protocol+Kb+a.host+a.pathname+a.search+a.hash}
var k=g();if(k==cb){k=h()}if(k==cb){k=i()}if(k==cb&&j()){k=e(p.location.href)}k=f(k);return k}
function D(a){if(a.match(/^\//)){return a}if(a.match(/^[a-zA-Z]+:\/\//)){return a}return rstudio.__moduleBase+a}
function F(){var f=[];var g=V;function h(a,b){var c=f;for(var d=V,e=a.length-W;d<e;++d){c=c[a[d]]||(c[a[d]]=[])}c[a[e]]=b}
var i=[];var j=[];function k(a){var b=j[a](),c=i[a];if(b in c){return b}var d=[];for(var e in c){d[c[e]]=e}if(s){s(a,d,b)}throw null}
j[Lb]=function(){return __gwt_getMetaProperty(Lb)};i[Lb]={'emulated':V,'native':W,'strip':Mb};j[Nb]=function(){if(window.desktop)return _;return window.navigator.userAgent.indexOf(Ob)>V||window.navigator.userAgent.indexOf(Pb)>V?_:Qb};i[Nb]={'false':V,'true':W};j[Rb]=function(){if(window.remoteDesktop)return _;return window.navigator.userAgent.indexOf(Sb)>V?_:Qb};i[Rb]={'false':V,'true':W};j[Tb]=function(){var a=navigator.userAgent.toLowerCase();var b=p.documentMode;if(function(){return a.indexOf(Ub)!=-1}())return Vb;if(function(){return a.indexOf(Wb)!=-1&&(b>=gb&&b<Xb)}())return Yb;if(function(){return a.indexOf(Wb)!=-1&&(b>=Zb&&b<Xb)}())return $b;if(function(){return a.indexOf(Wb)!=-1&&(b>=_b&&b<Xb)}())return ac;if(function(){return a.indexOf(bc)!=-1||b>=Xb}())return cc;return cb};i[Tb]={'gecko1_8':V,'ie10':W,'ie8':Mb,'ie9':dc,'safari':ec};__gwt_isKnownPropertyValue=function(a,b){return b in i[a]};rstudio.__getPropMap=function(){var a={};for(var b in i){if(i.hasOwnProperty(b)){a[b]=k(b)}}return a};rstudio.__computePropValue=k;o.__gwt_activeModules[S].bindings=rstudio.__getPropMap;r(O,fc);if(q()){return D(gc)}var l;try{h([hc,Qb,_,cc],ic);h([hc,Qb,_,Vb],ic+jc);h([hc,_,_,cc],ic+kc);h([hc,_,_,Vb],ic+lc);h([hc,Qb,Qb,Yb],mc);h([hc,_,Qb,Yb],mc+jc);h([nc,Qb,_,cc],oc);h([nc,Qb,_,Vb],oc+jc);h([nc,_,_,cc],oc+kc);h([nc,_,_,Vb],oc+lc);h([hc,Qb,Qb,cc],pc);h([hc,Qb,Qb,Vb],pc+jc);h([hc,_,Qb,cc],pc+kc);h([hc,_,Qb,Vb],pc+lc);h([nc,Qb,Qb,cc],qc);h([nc,Qb,Qb,Vb],qc+jc);h([nc,_,Qb,cc],qc+kc);h([nc,_,Qb,Vb],qc+lc);h([nc,Qb,Qb,Yb],rc);h([nc,_,Qb,Yb],rc+jc);h([hc,Qb,_,Yb],sc);h([hc,_,_,Yb],sc+jc);h([nc,Qb,_,Yb],tc);h([nc,_,_,Yb],tc+jc);l=f[k(Lb)][k(Nb)][k(Rb)][k(Tb)];var m=l.indexOf(uc);if(m!=-1){g=parseInt(l.substring(m+W),gb);l=l.substring(V,m)}}catch(a){}rstudio.__softPermutationId=g;return D(l+vc)}
function G(){if(!o.__gwt_stylesLoaded){o.__gwt_stylesLoaded={}}r(wc,P);r(wc,xc)}
B();rstudio.__moduleBase=C();t[S].moduleBase=rstudio.__moduleBase;var H=F();if(o){var I=!!(o.location.protocol==yc||o.location.protocol==zc);o.__gwt_activeModules[S].canRedirect=I;function J(){var b=Ac;try{o.sessionStorage.setItem(b,b);o.sessionStorage.removeItem(b);return true}catch(a){return false}}
if(I&&J()){var K=Bc;var L=o.sessionStorage[K];if(!/^http:\/\/(localhost|127\.0\.0\.1)(:\d+)?\/.*$/.test(L)){if(L&&(window.console&&console.log)){console.log(Cc+L)}L=cb}if(L&&!o[K]){o[K]=true;o[K+Dc]=C();var M=p.createElement(kb);M.src=L;var N=p.getElementsByTagName(pb)[V];N.insertBefore(M,N.firstElementChild||N.children[V]);return false}}}G();r(O,xc);A(H);return true}
rstudio.succeeded=rstudio();