$wnd.rstudio.runAsyncCallback22("function Ryj(a){this.a=a}\nfunction iyj(a,b){this.a=a;this.b=b}\nfunction Wxj(a,b){a.k?jVd(4,'Stop R Markdown Rendering',\"The rendering of '\"+a.g+\"' is in progress. Do you \"+'want to terminate and close the tab?',false,new iyj(a,b),null,null,xdn,VSm,true):b.zm()}\nfunction Nyj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Tyj(a.a.b.a);m6h(a.a,a.a.a)}switch(a.c){case 1:Ufi(a.a.a,a.b[0]);break;case 2:Wxj(a.a.a,a.b[0]);break;case 3:Xxj(a.a.a);break;case 4:a.a.a.H.AE();break;case 5:a.a.a.H.BE();break;case 6:Yxj(a.a.a,a.b[0]);break;case 7:Zxj(a.a.a,a.b[0]);break;case 8:$xj(a.a.a,a.b[0]);break;case 9:_xj(a.a.a,a.b[0]);break;case 10:a.a.a.H.CE();break;case 11:a.a.a.H.DE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nxVc(6693,1,_Sm,iyj);_.zm=function jyj(){ayj(this.a);this.b.zm()};var j8b=JBd(6693);xVc(311,1,qgn);_.xm=function Qyj(){Nyj((new Ryj(this)).a)};xVc(6213,1,BSm,Ryj);_.zm=function Syj(){Nyj(this.a)};var s8b=JBd(6213);AJm(El)(22);\n//# sourceURL=rstudio-22.js\n")
