$wnd.rstudio.runAsyncCallback15("function KCi(){}\nfunction ICi(a){this.a=a}\nfunction NCi(a){this.a=a}\nfunction PCi(a){this.a=a}\nfunction PDi(a){this.a=a}\nfunction _Bi(a){this.a=a}\nfunction qXf(a){this.a=a}\nfunction EBi(a){QBi(a,new NCi(a))}\nfunction JBi(a){OVf(a.b,new PCi(a))}\nfunction IBi(a){Bhk(a.k,new ICi(a),new KCi,rEn)}\nfunction LBi(a){Bhk(a.k,new CCi(a,null),new ECi,QKn)}\nfunction MBi(a,b){Myf(a.d,new kUi(b,true),false)}\nfunction ZVf(a,b){(vVd(b),b)&&OBi(a.a,eEo,'')}\nfunction bCi(a,b){this.a=a;this.b=b;BOf.call(this)}\nfunction MCi(a,b){MBi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction PFh(a,b){uKh(a,IHn,'devtools_load_all_path',new lH,b)}\nfunction QBi(a,b){a.c!=null?MCi(b,a.c):PFh(a.i,new bCi(a,b))}\nfunction KBi(a){a.G.HG();Fm((ym(),xm),new _Bi(a))}\nfunction ZBi(){zNf.call(this,'Terminating Build...')}\nfunction OVf(a,b){AVf(a,dEo,dEo,RXf(a.g.b.package_dependencies,'roxygen'),nVf(a,'roxygen'),false,new qXf(b))}\nfunction BBi(a,b){var c,d;CPf(a.p.e,null);d=b.outputs;for(c=0;c<d.length;c++)YAi(a.p,d[c]);b.errors.length>0&&XAi(a.p,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?B4d(a.a.Cj,true,false):BPf(a.p.e);zXe(a.p.e.c.c)}\nfunction LDi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=oEi(a.a.b.a);gri(a.a,a.a.a)}switch(a.c){case 1:BBi(a.a.a,a.b[0]);break;case 2:a.a.a.G.FG();break;case 3:a.a.a.G.GG();break;case 4:OBi(a.a.a,Ilo,'');break;case 5:OBi(a.a.a,'build-binary-package','');break;case 6:OBi(a.a.a,'build-source-package','');break;case 7:OBi(a.a.a,'check-package','');break;case 8:OBi(a.a.a,'clean-all','');break;case 9:IBi(a.a.a);break;case 10:OBi(a.a.a,Jlo,'');break;case 11:JBi(a.a.a);break;case 12:KBi(a.a.a);break;case 13:LBi(a.a.a);break;case 14:wLh(a.a.a.i,new ZBi);break;case 15:OBi(a.a.a,'test-package','');break;case 18:a.a.a.G.IG();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nvar dEo='Building package documentation',eEo='roxygenize-package';pZc(2173,1,xdn,qXf);_.ot=function rXf(a){ZVf(this.a,a)};var Xjb=TGd(2173);pZc(6636,372,{},ZBi);_.nm=function $Bi(a){(vVd(a),a)||FYc().LB(3,'Error Terminating Build','Unable to terminate build. Please try again.').MB()};var ZSb=TGd(6636);pZc(6637,1,Cdn,_Bi);_.zm=function aCi(){zXe(this.a.p.e.c.c)};var $Sb=TGd(6637);pZc(6638,53,{},bCi);_.uu=function cCi(a){this.a.c=a;MCi(this.b,this.a.c)};var _Sb=TGd(6638);pZc(6629,1,Cdn,ICi);_.zm=function JCi(){EBi(this.a)};var pTb=TGd(6629);pZc(6630,1,Cdn,KCi);_.zm=function LCi(){};var qTb=TGd(6630);pZc(6628,1,xdn,NCi);_.ot=function OCi(a){MCi(this,a)};var rTb=TGd(6628);pZc(6631,1,Cdn,PCi);_.zm=function QCi(){OBi(this.a,eEo,'')};var sTb=TGd(6631);pZc(250,1,JGn);_.xm=function ODi(){LDi((new PDi(this)).a)};pZc(6199,1,Cdn,PDi);_.zm=function QDi(){LDi(this.a)};var OTb=TGd(6199);s4m(Gl)(15);\n//# sourceURL=rstudio-15.js\n")
