$wnd.rstudio.runAsyncCallback16("function pRj(a){this.a=a}\nfunction OPj(a,b){this.a=a;this.b=b;Mbe.call(this)}\nfunction rPj(a,b){a.a=b;EQj(a.n,nPj(a,null),a.a.file_path)}\nfunction tPj(a,b){b.slide_index==0&&Y9h(a.n);a.a=b;EQj(a.n,nPj(a,null),a.a.file_path)}\nfunction zPj(a){yYe('Opening Presentation...',Tqd());Bff(a.c,new whf,false)}\nfunction oPj(a){var b;b=Luf(new Muf(0,'Closing Presentation...'));djh(a.j,new OPj(a,b))}\nfunction djh(a,b){ooh(a,cgn,'close_presentation_pane',new tE,b)}\nfunction yPj(a){var b;a.G.sE();!!a.a&&a.a.active&&(b=M8d(nh(a.n.d).contentWindow),!(!gDd(YRm,b)&&!gDd('javascript:void(0)',b)))&&rPj(a,a.a)}\nfunction lRj(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=_Rj(a.a.b.a);a5h(a.a,a.a.a)}switch(a.c){case 1:oPj((c=a.a.a,a.b[0],c));break;case 2:tPj(a.a.a,a.b[0]);break;case 3:a.a.a.G.qE();break;case 4:a.a.a.G.rE();break;case 5:yPj(a.a.a);break;case 6:zPj((b=a.a.a,a.b[0],b));break;case 7:a.a.a.G.tE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nkVc(6610,32,{},OPj);_.vt=function QPj(a){var b;Bff((b=this,a,b).a.c,new whf,false)};_.ut=function PPj(a){cuf(this.b,a.a?a.a.c:a.d)};var Ycc=wBd(6610);kVc(447,1,dfn);_.xm=function oRj(){lRj((new pRj(this)).a)};kVc(6174,1,oRm,pRj);_.zm=function qRj(){lRj(this.a)};var vdc=wBd(6174);nIm(El)(16);\n//# sourceURL=rstudio-16.js\n")
