$wnd.rstudio.runAsyncCallback16("function Hek(a){this.a=a}\nfunction edk(a,b){this.a=a;this.b=b;Bhe.call(this)}\nfunction Jck(a,b){a.a=b;Wdk(a.o,Fck(a,null),a.a.file_path)}\nfunction Lck(a,b){b.slide_index==0&&pxi(a.o);a.a=b;Wdk(a.o,Fck(a,null),a.a.file_path)}\nfunction Rck(a){Wff('Opening Presentation...',Uvd());azf(a.c,new XAf,false)}\nfunction Gck(a){var b;b=lOf(new mOf(0,'Closing Presentation...'));vGh(a.k,new edk(a,b))}\nfunction vGh(a,b){GLh(a,VIn,'close_presentation_pane',new lH,b)}\nfunction Qck(a){var b;a.H.RG();!!a.a&&a.a.active&&(b=Bee(nh(a.o.d).contentWindow),!(!QId(xfn,b)&&!QId('javascript:void(0)',b)))&&Jck(a,a.a)}\nfunction Dek(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=rfk(a.a.b.a);tsi(a.a,a.a.a)}switch(a.c){case 1:Gck((c=a.a.a,a.b[0],c));break;case 2:Lck(a.a.a,a.b[0]);break;case 3:a.a.a.H.PG();break;case 4:a.a.a.H.QG();break;case 5:Qck(a.a.a);break;case 6:Rck((b=a.a.a,a.b[0],b));break;case 7:a.a.a.H.SG();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nCZc(6663,32,{},edk);_.uu=function gdk(a){var b;azf((b=this,a,b).a.c,new XAf,false)};_.tu=function fdk(a){ENf(this.b,a.a?a.a.c:a.d)};var Ygc=eHd(6663);CZc(446,1,WHn);_.xm=function Gek(){Dek((new Hek(this)).a)};CZc(6227,1,Pen,Hek);_.zm=function Iek(){Dek(this.a)};var vhc=eHd(6227);F5m(Gl)(16);\n//# sourceURL=rstudio-16.js\n")
