$wnd.rstudio.runAsyncCallback26("function dVd(){}\nfunction hBj(){}\nfunction KBj(a){this.a=a}\nfunction aBj(a,b){WDj(a.c,b)}\nfunction LUd(a){var b;IUd(a);b=0;while(a.a.et(new dVd)){b=QYc(b,1)}return b}\nfunction EEj(a){var b,c,d;d=new igd;for(c=new ane((new $me(q8d(a.g))).a);c.b.length>c.a;){b=c.b[c.a++];Ufd(d,a.g[b])}return d}\nfunction VAj(a,b){var c,d;c=EEj(qFj(a.d.a));if(c.a.length==0){jIj(a.b,false);b.zm()}d=LUd(MUd(new QUd(null,new eSd(c)),new hBj));if(RYc(d,0)>0){FYc().LB(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(RYc(d,1)>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.').MB();return}jIj(a.b,false);b.zm()}\nfunction GBj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=xFj(a.a.b.a);gri(a.a,a.a.a)}switch(a.c){case 1:VAj(a.a.a,a.b[0]);break;case 2:WAj(a.a.a);break;case 3:a.a.a.G.FG();break;case 4:a.a.a.G.GG();break;case 5:XAj(a.a.a,a.b[0]);break;case 6:YAj(a.a.a,a.b[0]);break;case 7:ZAj(a.a.a,a.b[0]);break;case 8:$Aj(a.a.a,a.b[0]);break;case 9:_Aj(a.a.a,a.b[0]);break;case 10:a.a.a.G.HG();break;case 11:a.a.a.G.IG();break;case 12:aBj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\npZc(2081,1,{},dVd);_.it=function eVd(a){};var HZ=TGd(2081);pZc(6735,1,{},hBj);_.jt=function iBj(a){return a.type==1&&a.state==2};var a7b=TGd(6735);pZc(313,1,JGn);_.xm=function JBj(){GBj((new KBj(this)).a)};pZc(6263,1,Cdn,KBj);_.zm=function LBj(){GBj(this.a)};var h7b=TGd(6263);s4m(Gl)(26);\n//# sourceURL=rstudio-26.js\n")
