$wnd.rstudio.runAsyncCallback7("function PTj(a){this.a=a}\nfunction ZSj(a,b){this.a=a;this.b=b}\nfunction VSj(a,b){b==null?_4d(a,sto):_4d(a,b)}\nfunction iTj(a,b){Zh(a.d,new Dfe(false));_Sj(a.d,b,0)}\nfunction KIh(a,b){uKh(a,IHn,'markers_tab_closed',new lH,b)}\nfunction WSj(a,b){var c,d,e,f,g,h,i;d=a.p;grd(d.n);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new ZSj(a,f);e=new S$c(Q$c(new R$c,f).a.a);Ccf(d,new nsd(e,c))}}\nfunction _Sj(a,b,c){var d;Elg(a.b);VSj(a.c,null);WSj(a.c,bJ(YI(QX,1),b5m,2,6,[]));if(b.markers){d=b.markers;Ilg(a.b,null,d.base_path,d.markers,c,false);WSj(a.c,Zme(b.names));VSj(a.c,d.name)}}\nfunction hTj(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){Zh(a.d,new Dfe(true));_Sj(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=qlg(d));!!f&&L2f(a.b,(Bhe(),The(f.path,false,-1,0)),mZd(f.line,f.column),false)}}}else{Zh(a.d,new wfe)}}\nfunction LTj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=YTj(a.a.b.a);gri(a.a,a.a.a)}switch(a.c){case 1:gTj(a.a.a);break;case 2:a.a.a.G.FG();break;case 3:a.a.a.G.GG();break;case 4:KIh(a.a.a.c,new Bsf);break;case 5:hTj(a.a.a,a.b[0]);break;case 6:a.a.a.G.HG();break;case 7:a.a.a.G.IG();break;case 8:iTj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\npZc(7292,1,T6m,ZSj);_.zm=function $Sj(){TD(this.a,this.b)};var obc=TGd(7292);pZc(418,1,JGn);_.xm=function OTj(){LTj((new PTj(this)).a)};pZc(6038,1,Cdn,PTj);_.zm=function QTj(){LTj(this.a)};var Bbc=TGd(6038);s4m(Gl)(7);\n//# sourceURL=rstudio-7.js\n")
