$wnd.rstudio.runAsyncCallback16("function vSj(a){var b;uJm[b=++vJm]=vSj;this.a=(wJm[b]=YJm,a);vJm=b-1}\nfunction UQj(a,b){var c;uJm[c=++vJm]=UQj;this.a=(wJm[c]=QWm,a);this.b=b;Sbe.call(this);vJm=c-1}\nfunction uQj(a){var b,c;uJm[c=++vJm]=uQj;b=Uuf(new Vuf(0,(xJm='Closing Presentation...',wJm[c]=t$m,xJm)));ikh((wJm[c]=QWm,a).k,new UQj(a,b));vJm=c-1}\nfunction ikh(a,b){var c;uJm[c=++vJm]=ikh;tph((wJm[c]=HRo,a),eXn,'close_presentation_pane',(wJm[c]=Fgo,new oE),(xJm=(wJm[c]=HRo,b),wJm[c]=Ggo,xJm));vJm=c-1}\nfunction xQj(a,b){var c;uJm[c=++vJm]=xQj;(wJm[c]=ZWm,a).a=b;KRj((wJm[c]=aQm,a).o,tQj(a,(xJm=null,wJm[c]=CZm,xJm)),(xJm=(wJm[c]=yJm,(wJm[c]=aQm,a).a.file_path),wJm[c]=aQm,xJm));vJm=c-1}\nfunction FQj(a){var b;uJm[b=++vJm]=FQj;EYe('Opening Presentation...',(wJm[b]=NRm,Zqd()));Kff((wJm[b]=mln,(wJm[b]=MKm,a).c),new Fhf,(xJm=false,wJm[b]=UJm,xJm));vJm=b-1}\nfunction zQj(a,b){var c;uJm[c=++vJm]=zQj;(wJm[c]=GJm,(wJm[c]=bNm,b).slide_index)==0&&bbi((wJm[c]=JKm,a).o);wJm[c]=ZWm,(wJm[c]=YKm,a).a=b;KRj((wJm[c]=aQm,(wJm[c]=YKm,a).o),tQj((wJm[c]=YKm,a),(xJm=null,wJm[c]=CZm,xJm)),(xJm=(wJm[c]=yJm,(wJm[c]=aQm,(wJm[c]=YKm,a).a).file_path),wJm[c]=aQm,xJm));vJm=c-1}\nfunction EQj(a){var b,c;uJm[c=++vJm]=EQj;(wJm[c]=wKm,(wJm[c]=YOm,a).H).zE();!(wJm[c]=aOm,!(wJm[c]=xWm,a).a)&&(wJm[c]=HJm,(wJm[c]=zJm,a).a.active)&&(b=S8d((xJm=(wJm[c]=LUm,ph((xJm=(wJm[c]=_Nm,(wJm[c]=APm,a).o.d),wJm[c]=sKm,xJm)).contentWindow),wJm[c]=_Nm,xJm)),(wJm[c]=APm,!(!mDd(irn,(wJm[c]=QOm,b))&&!mDd('javascript:void(0)',(wJm[c]=NRm,b)))))&&xQj((wJm[c]=SKm,a),a.a);vJm=c-1}\nfunction rSj(b){var c,d,e,f;uJm[e=++vJm]=rSj;try{if((wJm[e]=DJm,b).c<0){f=true;return}if(wJm[e]=KNm,!(wJm[e]=FKm,b).a.a){wJm[e]=JJm,(wJm[e]=JJm,b).a.a=fTj((wJm[e]=vLm,b.a.b.a));f6h((wJm[e]=TKm,b).a,b.a.a)}switch((wJm[e]=HLm,b).c){case 1:uQj((d=(wJm[e]=LJm,b).a.a,b.b[0],d));break;case 2:zQj((wJm[e]=oKm,b).a.a,b.b[0]);break;case 3:(wJm[e]=zRm,(wJm[e]=WJm,b).a.a.H).xE();break;case 4:(wJm[e]=uNm,(wJm[e]=$Lm,b).a.a.H).yE();break;case 5:EQj((wJm[e]=_Lm,b).a.a);break;case 6:FQj((c=(wJm[e]=IOm,b).a.a,b.b[0],c));break;case 7:(wJm[e]=tKm,(wJm[e]=BRm,b).a.a.H).AE();}}catch(a){a=PUc(a);vJm=(wJm[e]=PKm,e);throw QUc(a)}finally{(wJm[e]=hNm,b).c<=0&&b.b[0]!=null&&b.b[0].zm();f&&(vJm=e-1)}vJm=e-1}\nqVc(6621,32,{},UQj);_.st=function WQj(a){var b,c;uJm[c=++vJm]=WQj;Kff((wJm[c]=mln,(wJm[c]=TPm,(wJm[c]=TYm,b=this,a,b).a).c),new Fhf,(xJm=false,wJm[c]=UJm,xJm));vJm=c-1};_.rt=function VQj(a){var b;uJm[b=++vJm]=VQj;luf((wJm[b]=NYm,this.b),(xJm=(wJm[b]=UKm,a.a)?(wJm[b]=IJm,(wJm[b]=LJm,(wJm[b]=NYm,a).a).c):(wJm[b]=nKm,(wJm[b]=NYm,a).d),wJm[b]=NYm,xJm));vJm=b-1};var bdc=CBd(6621);qVc(446,1,yUn);_.xm=function uSj(){var a;uJm[a=++vJm]=uSj;rSj((wJm[a]=$Jm,(new vSj((xJm=this,wJm[a]=YJm,xJm))).a));vJm=a-1};qVc(6185,1,yqn,vSj);_.zm=function wSj(){var a;uJm[a=++vJm]=wSj;rSj((wJm[a]=$Jm,this.a));vJm=a-1};var Adc=CBd(6185);tJm(Gl)(16);\n//# sourceURL=rstudio-16.js\n")
