$wnd.rstudio.runAsyncCallback9("function Lxj(a){this.a=a}\nfunction Dwj(a){a.G.HG();s_e(a.i.n)}\nfunction Bwj(a){dwi(a.i);AMf(a.a,'Load History','loadhistory')}\nfunction Cwj(a){dwi(a.i);FMf(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction Hxj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=oyj(a.a.b.a);gri(a.a,a.a.a)}switch(a.c){case 1:a.a.a.G.FG();break;case 2:a.a.a.G.GG();break;case 3:Bwj(a.a.a);break;case 4:Cwj(a.a.a);break;case 5:Dwj(a.a.a);break;case 6:a.a.a.G.IG();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\npZc(499,1,JGn);_.xm=function Kxj(){Hxj((new Lxj(this)).a)};pZc(6134,1,Cdn,Lxj);_.zm=function Mxj(){Hxj(this.a)};var l6b=TGd(6134);s4m(Gl)(9);\n//# sourceURL=rstudio-9.js\n")
