$wnd.rstudio.runAsyncCallback14("function wgm(a){this.a=a}\nfunction nAm(){Fvf.call(this)}\nfunction pqh(a,b){Aph(a,phn,'svn_cleanup',new tE,b)}\nfunction sgm(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Czm(a.a.b.a);m6h(a.a,a.a.a)}switch(a.c){case 1:a.a.a.c.H.AE();break;case 2:a.a.a.c.H.BE();break;case 3:a.a.a.c.H.CE();break;case 4:Ifm(a.a.a,a.b[0]);break;case 5:Jfm(a.a.a,a.b[0]);break;case 6:a.a.a.c.CK();break;case 7:a.a.a.c.DK();break;case 8:a.a.a.c.EK();break;case 9:a.a.a.c.FK();break;case 10:a.a.a.c.GK();break;case 11:a.a.a.c.HK();break;case 12:Kfm(a.a.a,a.b[0]);break;case 13:a.a.a.c.IK();break;case 14:Lfm(a.a.a,a.b[0]);break;case 15:a.a.a.c.H.DE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nxVc(275,1,qgn);_.xm=function vgm(){sgm((new wgm(this)).a)};xVc(6160,1,BSm,wgm);_.zm=function xgm(){sgm(this.a)};var oNc=JBd(6160);xVc(7243,1552,Fan);_.CK=function Vtm(){};_.DK=function Wtm(){Stm(this,false,null,Ggm(this.i.k))};_.EK=function Xtm(){xum(this.b,Ggm(this.i.k))};_.FK=function Ytm(){dnh(this.b.c,new Bum)};_.GK=function Ztm(){enh(this.b.c,new Dum)};_.HK=function $tm(){fnh(this.b.c,new Fum)};_.IK=function _tm(){Stm(this,true,null,new Kbd)};xVc(6065,52,{},nAm);_.vt=function oAm(a){rde(new kim(a),true)};var dSc=JBd(6065);xVc(7251,1552,Fan);_.CK=function mBm(){pqh(this.c,new ijm('SVN Cleanup','Cleaning up working directory...',750))};_.DK=function nBm(){rde(xDm(this.a.d.a),true)};_.EK=function oBm(){Wzm(this.a)};_.FK=function pBm(){Aqh(this.a.f,new lAm)};_.GK=function qBm(){Aqh(this.a.f,new nAm)};_.HK=function rBm(){};_.IK=function sBm(){jBm(this,null,new Kbd)};AJm(El)(14);\n//# sourceURL=rstudio-14.js\n")
