$wnd.rstudio.runAsyncCallback15("function Phi(){}\nfunction ehi(a){this.a=a}\nfunction Nhi(a){this.a=a}\nfunction Shi(a){this.a=a}\nfunction Uhi(a){this.a=a}\nfunction Uii(a){this.a=a}\nfunction uEf(a){this.a=a}\nfunction Jgi(a){Vgi(a,new Shi(a))}\nfunction Ogi(a){SCf(a.b,new Uhi(a))}\nfunction Ngi(a){JWj(a.k,new Nhi(a),new Phi,Wdn)}\nfunction Qgi(a){JWj(a.k,new Hhi(a,null),new Jhi,zkn)}\nfunction Rgi(a,b){Rff(a.d,new qzi(b,true),false)}\nfunction bDf(a,b){(lQd(b),b)&&Tgi(a.a,qco,'')}\nfunction ghi(a,b){this.a=a;this.b=b;Fvf.call(this)}\nfunction Rhi(a,b){Rgi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction Vkh(a,b){Aph(a,phn,'devtools_load_all_path',new tE,b)}\nfunction Vgi(a,b){a.c!=null?Rhi(b,a.c):Vkh(a.i,new ghi(a,b))}\nfunction Pgi(a){a.H.CE();Dm((wm(),vm),new ehi(a))}\nfunction chi(){Duf.call(this,'Terminating Build...')}\nfunction SCf(a,b){ECf(a,pco,pco,VEf(a.g.b.package_dependencies,'roxygen'),rCf(a,'roxygen'),false,new uEf(b))}\nfunction Ggi(a,b){var c,d;Gwf(a.p.e,null);d=b.outputs;for(c=0;c<d.length;c++)bgi(a.p,d[c]);b.errors.length>0&&agi(a.p,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?k_d(a.a.Cj,true,false):Fwf(a.p.e);REe(a.p.e.c.c)}\nfunction Qii(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=tji(a.a.b.a);m6h(a.a,a.a.a)}switch(a.c){case 1:Ggi(a.a.a,a.b[0]);break;case 2:a.a.a.H.AE();break;case 3:a.a.a.H.BE();break;case 4:Tgi(a.a.a,zWn,'');break;case 5:Tgi(a.a.a,'build-binary-package','');break;case 6:Tgi(a.a.a,'build-source-package','');break;case 7:Tgi(a.a.a,'check-package','');break;case 8:Tgi(a.a.a,'clean-all','');break;case 9:Ngi(a.a.a);break;case 10:Tgi(a.a.a,AWn,'');break;case 11:Ogi(a.a.a);break;case 12:Pgi(a.a.a);break;case 13:Qgi(a.a.a);break;case 14:Cqh(a.a.a.i,new chi);break;case 15:Tgi(a.a.a,'test-package','');break;case 18:a.a.a.H.DE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nvar pco='Building package documentation',qco='roxygenize-package';xVc(2159,1,wSm,uEf);_.os=function vEf(a){bDf(this.a,a)};var zgb=JBd(2159);xVc(6607,373,{},chi);_.nm=function dhi(a){(lQd(a),a)||TUc().vA(3,'Error Terminating Build','Unable to terminate build. Please try again.').wA()};var HPb=JBd(6607);xVc(6608,1,BSm,ehi);_.zm=function fhi(){REe(this.a.p.e.c.c)};var IPb=JBd(6608);xVc(6609,52,{},ghi);_.vt=function hhi(a){this.a.c=a;Rhi(this.b,this.a.c)};var JPb=JBd(6609);xVc(6600,1,BSm,Nhi);_.zm=function Ohi(){Jgi(this.a)};var ZPb=JBd(6600);xVc(6601,1,BSm,Phi);_.zm=function Qhi(){};var $Pb=JBd(6601);xVc(6599,1,wSm,Shi);_.os=function Thi(a){Rhi(this,a)};var _Pb=JBd(6599);xVc(6602,1,BSm,Uhi);_.zm=function Vhi(){Tgi(this.a,qco,'')};var aQb=JBd(6602);xVc(251,1,qgn);_.xm=function Tii(){Qii((new Uii(this)).a)};xVc(6170,1,BSm,Uii);_.zm=function Vii(){Qii(this.a)};var wQb=JBd(6170);AJm(El)(15);\n//# sourceURL=rstudio-15.js\n")
