$wnd.rstudio.runAsyncCallback16("function CSj(a){this.a=a}\nfunction _Qj(a,b){this.a=a;this.b=b;Zbe.call(this)}\nfunction EQj(a,b){a.a=b;RRj(a.o,AQj(a,null),a.a.file_path)}\nfunction GQj(a,b){b.slide_index==0&&ibi(a.o);a.a=b;RRj(a.o,AQj(a,null),a.a.file_path)}\nfunction MQj(a){LYe('Opening Presentation...',erd());Rff(a.c,new Mhf,false)}\nfunction BQj(a){var b;b=_uf(new avf(0,'Closing Presentation...'));pkh(a.k,new _Qj(a,b))}\nfunction pkh(a,b){Aph(a,phn,'close_presentation_pane',new tE,b)}\nfunction LQj(a){var b;a.H.CE();!!a.a&&a.a.active&&(b=Z8d(nh(a.o.d).contentWindow),!(!tDd(jTm,b)&&!tDd('javascript:void(0)',b)))&&EQj(a,a.a)}\nfunction ySj(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=mTj(a.a.b.a);m6h(a.a,a.a.a)}switch(a.c){case 1:BQj((c=a.a.a,a.b[0],c));break;case 2:GQj(a.a.a,a.b[0]);break;case 3:a.a.a.H.AE();break;case 4:a.a.a.H.BE();break;case 5:LQj(a.a.a);break;case 6:MQj((b=a.a.a,a.b[0],b));break;case 7:a.a.a.H.DE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nxVc(6622,32,{},_Qj);_.vt=function bRj(a){var b;Rff((b=this,a,b).a.c,new Mhf,false)};_.ut=function aRj(a){suf(this.b,a.a?a.a.c:a.d)};var idc=JBd(6622);xVc(447,1,qgn);_.xm=function BSj(){ySj((new CSj(this)).a)};xVc(6186,1,BSm,CSj);_.zm=function DSj(){ySj(this.a)};var Hdc=JBd(6186);AJm(El)(16);\n//# sourceURL=rstudio-16.js\n")
