$wnd.rstudio.runAsyncCallback26("function jVd(){}\nfunction nCj(){}\nfunction QCj(a){var b;z5m[b=++A5m]=QCj;this.a=(B5m[b]=Ybn,a);A5m=b-1}\nfunction gCj(a,b){var c;z5m[c=++A5m]=gCj;aFj((B5m[c]=W7m,a).c,b);A5m=c-1}\nfunction RUd(a){var b,c,d;z5m[c=++A5m]=RUd;OUd((B5m[c]=Ekn,a));B5m[c]=nin,b=0;while((B5m[c]=atn,a).a.bt(new jVd)){b=WYc((B5m[c]=txn,b),1)}d=(B5m[c]=btn,b);A5m=c-1;return d}\nfunction KFj(a){var b,c,d,e,f;z5m[e=++A5m]=KFj;d=(B5m[e]=kbn,new ogd);for(B5m[e]=i9m,c=new gne((B5m[e]=P5m,(new ene((C5m=w8d((C5m=(B5m[e]=i9m,a).g,B5m[e]=F8m,C5m)),B5m[e]=Lan,C5m))).a));(B5m[e]=K9m,(B5m[e]=V5m,(B5m[e]=i9m,c).b).length)>(B5m[e]=V5m,(B5m[e]=i9m,c).a);){B5m[e]=i9m,b=(B5m[e]=R5m,(B5m[e]=W5m,(B5m[e]=i9m,c).b)[B5m[e]=W5m,(B5m[e]=i9m,c).a++]);$fd((B5m[e]=k9m,d),(C5m=(B5m[e]=D8m,a.g[b]),B5m[e]=k9m,C5m))}f=(B5m[e]=l9m,d);A5m=e-1;return f}\nfunction _Bj(a,b){var c,d,e;z5m[e=++A5m]=_Bj;c=KFj((C5m=wGj((B5m[e]=O5m,(B5m[e]=Wan,a).d.a)),B5m[e]=Wan,C5m));if((B5m[e]=q9m,(B5m[e]=G5m,c).a).length==0){pJj((B5m[e]=_8m,a).b,false);(B5m[e]=Man,b).zm()}d=RUd(SUd(new WUd(null,(C5m=new kSd((C5m=(B5m[e]=L9m,c),B5m[e]=H6m,C5m)),B5m[e]=h7m,C5m)),(C5m=(B5m[e]=van,new nCj),B5m[e]=L9m,C5m)));if(XYc((B5m[e]=M7m,d),(C5m=0,B5m[e]=F6m,C5m))>0){(C5m=(B5m[e]=M5m,LYc()).QB(1,'Local Jobs Still Running',(C5m='The Jobs tab cannot be closed while there '+(XYc((B5m[e]=N7m,d),(C5m=1,B5m[e]=F6m,C5m))>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.',B5m[e]=M5m,C5m)),B5m[e]=Fan,C5m).RB();A5m=e-1;return}pJj((B5m[e]=u9m,a).b,false);(B5m[e]=v9m,b).zm();A5m=e-1}\nfunction MCj(b){var c,d;z5m[c=++A5m]=MCj;try{if((B5m[c]=R6m,b).c<0){d=true;return}if(B5m[c]=Z9m,!(B5m[c]=Nan,b).a.a){B5m[c]=Kdn,(B5m[c]=Kdn,b).a.a=DGj((B5m[c]=San,b.a.b.a));msi((B5m[c]=p9m,b).a,b.a.a)}switch((B5m[c]=Ghn,b).c){case 1:_Bj((B5m[c]=Gdn,b).a.a,b.b[0]);break;case 2:aCj((B5m[c]=E8m,b).a.a);break;case 3:(B5m[c]=$5m,(B5m[c]=$8m,b).a.a.H).MG();break;case 4:(B5m[c]=J9m,(B5m[c]=Ldn,b).a.a.H).NG();break;case 5:bCj((B5m[c]=L9m,b).a.a,b.b[0]);break;case 6:cCj((B5m[c]=m9m,b).a.a,b.b[0]);break;case 7:dCj((B5m[c]=K7m,b).a.a,b.b[0]);break;case 8:eCj((B5m[c]=N7m,b).a.a,b.b[0]);break;case 9:fCj((B5m[c]=Yan,b).a.a,b.b[0]);break;case 10:(B5m[c]=M6m,(B5m[c]=y6m,b).a.a.H).OG();break;case 11:(B5m[c]=K6m,(B5m[c]=Fan,b).a.a.H).PG();break;case 12:gCj((B5m[c]=z6m,b).a.a,b.b[0]);}}catch(a){a=UYc(a);A5m=(B5m[c]=Van,c);throw VYc(a)}finally{(B5m[c]=B6m,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(A5m=c-1)}A5m=c-1}\nvZc(2085,1,{},jVd);_.ft=function kVd(a){};var AZ=ZGd(2085);vZc(6746,1,{},nCj);_.gt=function oCj(a){var b,c;z5m[b=++A5m]=oCj;c=(B5m[b]=van,a).type==1&&(B5m[b]=Xan,a.state)==2;A5m=b-1;return c};var f7b=ZGd(6746);vZc(313,1,bko);_.xm=function PCj(){var a;z5m[a=++A5m]=PCj;MCj((B5m[a]=P6m,(new QCj((C5m=this,B5m[a]=Ybn,C5m))).a));A5m=a-1};vZc(6274,1,TOn,QCj);_.zm=function RCj(){var a;z5m[a=++A5m]=RCj;MCj((B5m[a]=P6m,this.a));A5m=a-1};var m7b=ZGd(6274);y5m(Il)(26);\n//# sourceURL=rstudio-26.js\n")
