$wnd.rstudio.runAsyncCallback3("function tsi(a){this.a=a}\nfunction vsi(a){this.a=a}\nfunction Esi(a){this.a=a}\nfunction Hqe(a,b){var c;for(c=0;c<a.p.a.length;c++){if(Yfd(a.p,c).oO==b){vte(a.s,SHd(c));break}}}\nfunction ssi(a,b){this.c=a;this.b=Mbi(a.c,dUn,eUn,cfn).uG();this.a=Mbi(a.c,fUn,gUn,hUn).uG();Yh(b,new tsi(this),yD?yD:(yD=new TA))}\nfunction qsi(a){var b;b=rsi(a,'weaving Rnw files',a.b,Mbi(a.c.c,dUn,eUn,cfn));b||rsi(a,'LaTeX typesetting',a.a,Mbi(a.c.c,fUn,gUn,hUn))}\nfunction osi(a,b,c){var d;d=Ymi(a.b.a);Mqe(d,kei(TBg((nqf(),mqf).a)));!!b&&Hqe(d,b);Sqe(d,c);Iie(d,true);new ssi(a,d);(cwf()||!!$wnd.remoteDesktop)&&gwf()}\nfunction Asi(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=$yi(a.a.b.a));switch(a.c){case 1:osi(a.a.a,null,true);break;case 2:osi(a.a.a,a.b[0],zGd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nfunction rsi(a,b,c,d){if(WJ(c)!==WJ(d.uG())&&WJ(d.Jq())!==WJ(d.uG())){y$d(2,'Project Option Unchanged','You changed the global option for '+b+cdn+d.uG()+', however the current project is '+'still configured to use '+d.Jq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new vsi(a),true);return true}else{return false}}\npZc(2756,1,{},ssi);var qQb=TGd(2756);pZc(2757,1,ybn,tsi);_.Jn=function usi(a){qsi(this.a)};var oQb=TGd(2757);pZc(2758,1,aen,vsi);_.zm=function wsi(){h4d(this.a.c.a.Ug)};var pQb=TGd(2758);pZc(616,1,JGn);_.xm=function Dsi(){Asi((new Esi(this)).a)};pZc(2810,1,Cdn,Esi);_.zm=function Fsi(){Asi(this.a)};var rQb=TGd(2810);s4m(Gl)(3);\n//# sourceURL=rstudio-3.js\n")
