$wnd.rstudio.runAsyncCallback22("function Exj(a){this.a=a}\nfunction Xwj(a,b){this.a=a;this.b=b}\nfunction Jwj(a,b){a.k?YUd(4,'Stop R Markdown Rendering',\"The rendering of '\"+a.g+\"' is in progress. Do you \"+'want to terminate and close the tab?',false,new Xwj(a,b),null,null,lcn,IRm,true):b.zm()}\nfunction Axj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Gxj(a.a.b.a);a5h(a.a,a.a.a)}switch(a.c){case 1:Iei(a.a.a,a.b[0]);break;case 2:Jwj(a.a.a,a.b[0]);break;case 3:Kwj(a.a.a);break;case 4:a.a.a.G.qE();break;case 5:a.a.a.G.rE();break;case 6:Lwj(a.a.a,a.b[0]);break;case 7:Mwj(a.a.a,a.b[0]);break;case 8:Nwj(a.a.a,a.b[0]);break;case 9:Owj(a.a.a,a.b[0]);break;case 10:a.a.a.G.sE();break;case 11:a.a.a.G.tE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nkVc(6681,1,ORm,Xwj);_.zm=function Ywj(){Pwj(this.a);this.b.zm()};var Z7b=wBd(6681);kVc(311,1,dfn);_.xm=function Dxj(){Axj((new Exj(this)).a)};kVc(6201,1,oRm,Exj);_.zm=function Fxj(){Axj(this.a)};var g8b=wBd(6201);nIm(El)(22);\n//# sourceURL=rstudio-22.js\n")
