$wnd.rstudio.runAsyncCallback20("function aKj(a){this.a=a}\nfunction eKj(a){this.a=a}\nfunction YKj(a){this.a=a}\nfunction iKj(a,b){this.a=a;this.b=b}\nfunction yJj(a){CJj(a,false);APf(a.a)}\nfunction UJj(a){a.G.HG();Fm((ym(),xm),new eKj(a))}\nfunction LJj(a,b){var c;c=new aXd(b,new aKj(a));xIh(a.d,new cKj(a,c))}\nfunction lFh(a,b){uKh(a,IHn,'compile_pdf_closed',new lH,b)}\nfunction xIh(a,b){uKh(a,IHn,'is_compile_pdf_running',new lH,b)}\nfunction cKj(a,b){this.a=a;this.b=b;zNf.call(this,'Closing Compile PDF...')}\nfunction MJj(a,b){Zh(a.g,new Dfe(false));yJj(a.g);KJj(a,b.target_file);EJj(a.g,qPf(1,b.output));b.errors.length>0&&DJj(a.g,b.errors);b.running||zJj(a.g);zXe(a.g.a.c.c)}\nfunction UKj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=fLj(a.a.b.a);gri(a.a,a.a.a)}switch(a.c){case 1:PAi(a.a.a,a.b[0]);break;case 2:LJj(a.a.a,a.b[0]);break;case 3:MJj(a.a.a,a.b[0]);break;case 4:PJj(a.a.a);break;case 5:a.a.a.G.FG();break;case 6:a.a.a.G.GG();break;case 7:QJj(a.a.a,a.b[0]);break;case 8:RJj(a.a.a,a.b[0]);break;case 9:SJj(a.a.a,a.b[0]);break;case 10:TJj(a.a.a,a.b[0]);break;case 11:KJj(a.a.a,a.b[0].a.target_file);break;case 12:UJj(a.a.a);break;case 13:a.a.a.G.IG();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\npZc(6710,1,Cdn,aKj);_.zm=function bKj(){lFh(this.a.d,new Bsf)};var R8b=TGd(6710);pZc(6711,372,{},cKj);_.nm=function dKj(a){(vVd(a),a)?y$d(2,'Stop Running Compile','There is a PDF compilation currently running. If you close the Compile PDF tab it will be terminated. Are you sure you want to stop the running PDF compilation?',new iKj(this.a,this.b),false):_Wd(this.b)};var S8b=TGd(6711);pZc(6712,1,Cdn,eKj);_.zm=function fKj(){zXe(this.a.g.a.c.c)};var T8b=TGd(6712);pZc(6714,1,aen,iKj);_.zm=function jKj(){VJj(this.a,this.b)};var V8b=TGd(6714);pZc(285,1,JGn);_.xm=function XKj(){UKj((new YKj(this)).a)};pZc(6238,1,Cdn,YKj);_.zm=function ZKj(){UKj(this.a)};var f9b=TGd(6238);s4m(Gl)(20);\n//# sourceURL=rstudio-20.js\n")
