$wnd.rstudio.runAsyncCallback16("function udk(a){this.a=a}\nfunction Tbk(a,b){this.a=a;this.b=b;ohe.call(this)}\nfunction wbk(a,b){a.a=b;Jck(a.n,sbk(a,null),a.a.file_path)}\nfunction ybk(a,b){b.slide_index==0&&dwi(a.n);a.a=b;Jck(a.n,sbk(a,null),a.a.file_path)}\nfunction Ebk(a){Jff('Opening Presentation...',Hvd());Myf(a.c,new HAf,false)}\nfunction tbk(a){var b;b=XNf(new YNf(0,'Closing Presentation...'));jFh(a.j,new Tbk(a,b))}\nfunction jFh(a,b){uKh(a,IHn,'close_presentation_pane',new lH,b)}\nfunction Dbk(a){var b;a.G.HG();!!a.a&&a.a.active&&(b=oee(nh(a.n.d).contentWindow),!(!DId(ken,b)&&!DId('javascript:void(0)',b)))&&wbk(a,a.a)}\nfunction qdk(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=eek(a.a.b.a);gri(a.a,a.a.a)}switch(a.c){case 1:tbk((c=a.a.a,a.b[0],c));break;case 2:ybk(a.a.a,a.b[0]);break;case 3:a.a.a.G.FG();break;case 4:a.a.a.G.GG();break;case 5:Dbk(a.a.a);break;case 6:Ebk((b=a.a.a,a.b[0],b));break;case 7:a.a.a.G.IG();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\npZc(6651,32,{},Tbk);_.uu=function Vbk(a){var b;Myf((b=this,a,b).a.c,new HAf,false)};_.tu=function Ubk(a){oNf(this.b,a.a?a.a.c:a.d)};var Mgc=TGd(6651);pZc(446,1,JGn);_.xm=function tdk(){qdk((new udk(this)).a)};pZc(6215,1,Cdn,udk);_.zm=function vdk(){qdk(this.a)};var jhc=TGd(6215);s4m(Gl)(16);\n//# sourceURL=rstudio-16.js\n")
