$wnd.rstudio.runAsyncCallback3("function Fti(a){this.a=a}\nfunction Hti(a){this.a=a}\nfunction Qti(a){this.a=a}\nfunction Uqe(a,b){var c;for(c=0;c<a.p.a.length;c++){if(jgd(a.p,c).yO==b){Ite(a.s,dId(c));break}}}\nfunction Eti(a,b){this.c=a;this.b=Yci(a.c,pVn,qVn,pgn).EG();this.a=Yci(a.c,rVn,sVn,tVn).EG();Yh(b,new Fti(this),yD?yD:(yD=new TA))}\nfunction Cti(a){var b;b=Dti(a,'weaving Rnw files',a.b,Yci(a.c.c,pVn,qVn,pgn));b||Dti(a,'LaTeX typesetting',a.a,Yci(a.c.c,rVn,sVn,tVn))}\nfunction Ati(a,b,c){var d;d=ioi(a.b.a);Zqe(d,wfi(dDg((Aqf(),zqf).a)));!!b&&Uqe(d,b);dre(d,c);Vie(d,true);new Eti(a,d);(pwf()||!!$wnd.remoteDesktop)&&twf()}\nfunction Mti(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=kAi(a.a.b.a));switch(a.c){case 1:Ati(a.a.a,null,true);break;case 2:Ati(a.a.a,a.b[0],MGd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nfunction Dti(a,b,c,d){if(WJ(c)!==WJ(d.EG())&&WJ(d.Jq())!==WJ(d.EG())){L$d(2,'Project Option Unchanged','You changed the global option for '+b+pen+d.EG()+', however the current project is '+'still configured to use '+d.Jq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new Hti(a),true);return true}else{return false}}\nCZc(2762,1,{},Eti);var CQb=eHd(2762);CZc(2763,1,Lcn,Fti);_.Jn=function Gti(a){Cti(this.a)};var AQb=eHd(2763);CZc(2764,1,nfn,Hti);_.zm=function Iti(){u4d(this.a.c.a.Ug)};var BQb=eHd(2764);CZc(617,1,WHn);_.xm=function Pti(){Mti((new Qti(this)).a)};CZc(2816,1,Pen,Qti);_.zm=function Rti(){Mti(this.a)};var DQb=eHd(2816);F5m(Gl)(3);\n//# sourceURL=rstudio-3.js\n")
